<?php
/**
 * A tester class for the WebKDBDriver. To test the database class you
 * must edit the line: $driver = new WebKDBDriver('localhost','root','','test').
 * Also a test database must exists.
 * 
 * @package webkdb
 */
/**
 * Defines the basedir for the inclusions. Also used to see if a script
 * is included or directly accesed.
 */
define("WEBK_BASEDIR",str_replace("\\","/",dirname(dirname(__FILE__))));
ini_set('include_path', ini_get('include_path').PATH_SEPARATOR.WEBK_BASEDIR);

ob_start();

include_once("driver.php");

assert_options(ASSERT_ACTIVE,   true);
assert_options(ASSERT_BAIL,     true);
assert_options(ASSERT_WARNING,  false);
assert_options(ASSERT_CALLBACK, '__wk_assert_failure');

/**
 * Assertion function used on error.
 * 
 * @param string $script
 * @param integer $line
 * @param string $message
 */
function __wk_assert_failure($script, $line, $message){
	echo "FAIL!!!\n\n<h1>You have an error at line [{$line}] in script &laquo;{$script}&raquo;.</h1>";
	$data = ob_get_contents();
	ob_end_clean();

	echo nl2br($data);
}

try{
	echo "Connecting to the database...\t";
	$driver = new WebKDBDriver('localhost','root','','test');
	echo "OK\n\n";

	echo "Creating the `test_config` table...\t";
	$q=$driver->query("CREATE TABLE `test_config` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) COLLATE utf8_romanian_ci NOT NULL,
  `value` longtext COLLATE utf8_romanian_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `name` (`name`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_romanian_ci AUTO_INCREMENT=9;");
	assert($q==true);
	echo "OK\n\n";

	echo "Populating the `test_config` table...\t";
	$q=$driver->query("INSERT INTO `test_config` (`id`, `name`, `value`) VALUES
	   (1, 'element 1', 'valoare 1'),
	   (2, 'element 2', 'valoare 2'),
	   (3, 'element 3', 'valoare 3'),
	   (4, 'element 4', 'valoare 4'),
	   (5, 'element 5', 'valoare 5'),
	   (6, 'element 6', 'valoare 6'),
	   (7, 'element 7', 'valoare 7'),
	   (8, 'element 8', 'valoare 8');");
	assert($q==true);
	echo "OK\n\n";

	echo "Counting the data from the `test_config` table...\t";
	$q=$driver->query("SELECT * FROM `test_config`");
	$num_rows = $q->num_rows();
	assert($num_rows==$driver->query("SELECT COUNT(*) as `elements` FROM `test_config`")->row()->elements);
	echo "OK\n\n";

	echo "Inserting a new element into the `test_config` table...\t";
	$elm=$num_rows+1;
	$q=$driver->query("INSERT INTO `test_config` SET `id`={$elm}, `name`='element {$elm}', `value`='valoare {$elm}';");
	assert($q==true);
	echo "OK\n\n";

	echo "Verifying the ID...\t";
	$last_id=$driver->insert_id();
	assert($elm==$last_id);
	echo "OK\n\n";

	echo "Testing to see if the last inserted data is correct...\t";
	$q=$driver->query("SELECT * FROM `test_config` WHERE `id`='{$elm}'");
	$row=$q->row();
	assert($row->id==$elm);
	assert($row->name=="element {$elm}");
	assert($row->value=="valoare {$elm}");
	echo "OK\n\n";

	echo "Testing the update query...\t";
	$q=$driver->query("UPDATE `test_config` SET `name`='nume element {$elm}', value='valoare noua {$elm}' WHERE `id`='{$elm}'");
	assert($q==true);
	echo "OK\n\n";

	echo "Verifing the updated element...\t";
	$q=$driver->query("SELECT * FROM `test_config` WHERE `id`='{$elm}'");
	$row=$q->row();
	assert($row->id==$elm);
	assert($row->name=="nume element {$elm}");
	assert($row->value=="valoare noua {$elm}");
	echo "OK\n\n";

	echo "Counting the new data from the `test_config` table...\t";
	$q=$driver->query("SELECT * FROM `test_config`");
	$num_rows=$q->num_rows();
	assert($num_rows==$driver->query("SELECT COUNT(*) as `elements` FROM `test_config`")->row()->elements);
	echo "OK\n\n";

	echo "Deleting the new inserted data from the `test_config` table...\t";
	$q=$driver->query("DELETE FROM `test_config` WHERE `id`='{$last_id}';");
	assert($q==true);
	echo "OK\n\n";

	echo "Creating a new table...\t";
	$q=$driver->query("CREATE TABLE `test_table` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `test` varchar(255) COLLATE utf8_romanian_ci NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COLLATE=utf8_romanian_ci AUTO_INCREMENT=1;");
	assert($q==true);
	echo "OK\n\n";

	echo "We must have 0 elements in the new table...\t";
	$q=$driver->query("SELECT * FROM `test_table`");
	assert($q->num_rows()==0);
	echo "OK\n\n";

	echo "Adding elements into the new table...\t";
	for($i=1;$i<=10;$i++){
		$q=$driver->query("INSERT INTO `test_table` SET `test`='element {$i}';");
		assert($i==$driver->insert_id());
	}
	echo "OK\n\n";

	echo "We must have 10 elements in the new table...\t";
	$q=$driver->query("SELECT * FROM `test_table`");
	assert($q->num_rows()==10);
	echo "OK\n\n";

	echo "The elements are...\t";
	$q2=$driver->query("SELECT * FROM `test_config`");
	if($q2->num_rows()==10){
		echo "[EQUAL] ";
		assert($q->num_rows()==$q2->num_rows());
	}else{
		echo "[NOT EQUAL] ";
		assert($q->num_rows()!=$q2->num_rows());
	}
	echo "OK\n\n";

	echo "Emptying the new created table...\t";
	$q=$driver->query("TRUNCATE TABLE `test_table`");
	assert($q==true);
	$q=$driver->query("SELECT * FROM `test_table`");
	assert($q->num_rows()==0);
	echo "OK\n\n";

	echo "Deleting the new created table...\t";
	$q=$driver->query("DROP TABLE `test_table`");
	assert($q==true);
	echo "OK\n\n";

	echo "Deleting the `test_config` created table...\t";
	$q=$driver->query("DROP TABLE `test_config`");
	assert($q==true);
	echo "OK\n\n";

	echo "Tests are OK!\n";
}catch(WebKException $e){
	echo $e->message();
}

$data = ob_get_contents();
ob_end_clean();

echo nl2br($data);
/*File: database.test.php*/
/*Date: 23.07.2012*/
