<?php
/**
 * The query class used by the WebKDBDriver.
 * 
 * @package webkdb
 */
if(!defined("WEBK_BASEDIR")) die("Cannot open this file! Must be included.");

/**
 * The query class used to obtain data from the database.
 *
 * @package webkdb
 * @author thg2oo6
 * @copyright Copyright (c) 2012
 * @version 1.0
 * @access public
 */
class WQuery{
	/**
	 * The string of last query executed.
	 *
	 * @var string $_query_str.
	 */
	private $_query_str;

	/**
	 * The last query executed.
	 *
	 * @var mixed $_query
	 */
	private $_query;

	/**
	 * The connection with the database.
	 *
	 * @var mysqli $_connection
	 */
	private $_connection;

	/**
	 * Constructs the query element.
	 *
	 * @param resource $connection
	 */
	function __construct(&$connection){$this->_connection=&$connection;}

	/**
	 * Destroys the instance of the class.
	 *
	 */
	function __destruct(){}

	/**
	 * Returns the result of the query to be executed.
	 *
	 * @param $sql The sql query string to be executed.
	 * @return mixed
	 */
	final public function query($sql=""){
		if(empty($sql)) return $this->_query;

		$this->_query_str = $sql;
		$this->_query = $this->_connection->query($sql);

		return $this->_query;
	}

	/**
	 * Returns the ID of the sql insert query.
	 *
	 * @return integer
	 */
	final public function insert_id(){
		return $this->_connection->insert_id;
	}

	/**
	 * Returns the string of the last query.
	 *
	 * @return string
	 */
	final public function last_query(){
		return $this->_query_str;
	}

	/**
	 * Returns the string representation of the query.
	 *
	 * @return string
	 */
	final public function __toString(){
		return $this->last_query();
	}

	/**
	 * Tests to see if the last executed has errors or not.
	 *
	 * @return boolean
	 */
	final public function error(){
		if($this->error_no())
			return true;
		return false;
	}

	/**
	 * Returns the error code of the executed query.
	 *
	 * @return integer
	 */
	final public function error_no(){
		return $this->_connection->errno;
	}

	/**
	 * Returns the error string of the executed query.
	 *
	 * @returns string
	 */
	final public function error_str(){
		return $this->_connection->error;
	}
}

/*File: query.class.php*/
/*Date: 16.07.2012*/
