<?php
/**
 * The result class used by the WebKDBDriver.
 * 
 * @package webkdb
 */

if(!defined("WEBK_BASEDIR")) die("Cannot open this file! Must be included.");
require_once('query.class.php');

/**
 * Class used to return the results of an select query.
 *
 * @package webkdb
 * @author thg2oo6
 * @copyright Copyright (c) 2012
 * @version 1.0
 * @access public
 */
class WResult{
	/**
	 * The link with the mysql query result.
	 *
	 * @var mysqli_result $_query
	 */
	private $_query;

	/**
	 * Constructs the result element.
	 *
	 * @param mysqli_result $query The query result.
	 */
	function __construct($query){$this->_query=$query;}

	/**
	 * Destructs the class and frees the result.
	 */
	function __destruct(){
		if(!is_bool($this->_query)) $this->_query->free();
	}

	/**
	 * Returns an array with the database results represented as objects.
	 *
	 * @return mixed
	 */
	final public function result(){
		if(is_bool($this->_query))
			return $this->_query;

		$a = array();

		while($r=$this->_query->fetch_object()){
			$a[]=$r;
		}

		return $a;
	}

	/**
	 * Returns an array with the database results represented as associative array.
	 *
	 * @return array
	 */
	final public function result_array(){
		if(is_bool($this->_query))
			return $this->_query;

		$a=array();

		while($r=$this->_query->fetch_assoc()){
			$a[]=$r;
		}

		return $a;
	}

	/**
	 * Returns a row from the select query (object). In case of multiple rows it returns
	 * only the first one, or the specified one.
	 *
	 * @param $pos Fetches the row at the specified position.
	 * @return object
	 */
	final public function row($pos=0){
		if(is_bool($this->_query))
			return $this->_query;

		$this->_query->data_seek($pos);
		return $this->_query->fetch_object();
	}

	/**
	 * Returns a row from the select query (array). In case of multiple rows it returns
	 * only the first one, or the specified one.
	 *
	 * @param $pos Fetches the row at the specified position.
	 * @return array
	 */
	final public function row_array($pos=0){
		if(is_bool($this->_query))
			return $this->_query;

		$this->_query->data_seek($pos);
		return $this->_query->fetch_assoc();
	}

	/**
	 * Returns the number of the rows returned by the executed query.
	 *
	 * @return integer
	 */
	final public function num_rows(){
		if(is_bool($this->_query)) return 0;
		return $this->_query->num_rows;
	}
}

/*File: result.class.php*/
/*Date: 16.07.2012*/
